DENOFO models and choices
=========================

We provide a set of models and predefined choices which build our DENOFO 
annotation format. The heart of the format is the :class:`denofo.models.DeNovoGeneAnnotation`


Models
------

.. automodule:: denofo.models
    :members:
    :undoc-members:

Choices
-------

.. automodule:: denofo.choices
    :members:
    :undoc-members: